/**
 * PAC Reference Decoder.
 */

#include <stdio.h>
#include <stdlib.h>
#include "pac.h"


int
main (int argc, char **argv)
{
  PacObject_t *pac;
  PacImage_t *image;
  char *formats[4] = { "GRAY", "GRAY_ALPHA", "RGB", "RGB_ALPHA" };
  
  if (argc != 3)
    {
      fprintf (stderr, "usage: pacenc [PAC input file] [PNG output file]\n");
      exit (1);
    }
  
  if (! (pac = pac_new_obj ()))
    {
      pac_print_error ();
      exit (1);
    }
  
  if (! (image = pac_decode_from_file (pac, argv[1])))
    {
      pac_delete_obj (pac);
      pac_print_error ();
      exit (1);
    }
  
  printf ("Input:           %s\n", argv[1]);
  printf ("Format:          %s\n", formats[image->format]);
  printf ("Bits/Component:  %d\n", image->bits_per_component);
  printf ("Width:           %d\n", image->width);
  printf ("Height:          %d\n", image->height);

  if (png_encode_to_file (image, argv[2]))
    {
      pac_delete_obj (pac);
      pac_delete_image (image);
      pac_print_error ();
      exit (1);
    }
  
  pac_delete_obj (pac);
  pac_delete_image (image);
  
  return 0;
}
